@@ -3,7 +3,6 @@
 const {
     Gdk, GdkPixbuf, Gio, GLib, GObject, Gspell, Gtk, TelepathyGLib: Tp
 } = imports.gi;
-const Mainloop = imports.mainloop;
 
 const ChatView = imports.chatView;
 const { DropTargetIface } = imports.pasteManager;
@@ -19,10 +18,11 @@ var ChatEntry = GObject.registerClass({
     Properties: {
         'can-drop': GObject.ParamSpec.override('can-drop', DropTargetIface),
     },
-    Signals: { 'text-pasted': { param_types: [GObject.TYPE_STRING,
-                                              GObject.TYPE_INT] },
-               'image-pasted': { param_types: [GdkPixbuf.Pixbuf.$gtype] },
-               'file-pasted': { param_types: [Gio.File.$gtype] } },
+    Signals: {
+        'text-pasted': { param_types: [GObject.TYPE_STRING, GObject.TYPE_INT] },
+        'image-pasted': { param_types: [GdkPixbuf.Pixbuf.$gtype] },
+        'file-pasted': { param_types: [Gio.File.$gtype] }
+    }
 }, class ChatEntry extends Gtk.Entry {
     static get _checker() {
         if (!this.__checker)
@@ -106,8 +106,10 @@ var ChatEntry = GObject.registerClass({
 
 var NickPopover = GObject.registerClass({
     Template: 'resource:///org/gnome/Polari/ui/nick-popover.ui',
-    InternalChildren: ['nickEntry',
-                       'changeButton'],
+    InternalChildren: [
+        'nickEntry',
+        'changeButton'
+    ],
     Properties: {
         nick: GObject.ParamSpec.string('nick',
                                        'nick',
@@ -115,7 +117,9 @@ var NickPopover = GObject.registerClass({
                                        GObject.ParamFlags.READWRITE,
                                        '')
     },
-    Signals: { 'nick-changed': {} }
+    Signals: {
+        'nick-changed': {}
+    }
 }, class NickPopover extends Gtk.Popover {
     _init() {
         this._nick = '';
@@ -151,21 +155,23 @@ var NickPopover = GObject.registerClass({
 
 var EntryArea = GObject.registerClass({
     Template: 'resource:///org/gnome/Polari/ui/entry-area.ui',
-    InternalChildren: ['chatEntry',
-                       'nickButton',
-                       'nickLabel',
-                       'pasteBox',
-                       'confirmLabel',
-                       'uploadLabel',
-                       'cancelButton',
-                       'pasteButton'],
+    InternalChildren: [
+        'chatEntry',
+        'nickButton',
+        'nickLabel',
+        'pasteBox',
+        'confirmLabel',
+        'uploadLabel',
+        'cancelButton',
+        'pasteButton'
+    ],
     Properties: {
         'max-nick-chars': GObject.ParamSpec.uint('max-nick-chars',
                                                  'max-nick-chars',
                                                  'max-nick-chars',
                                                  GObject.ParamFlags.WRITABLE,
                                                  0, GLib.MAXUINT32, 0)
-    },
+    }
 }, class EntryArea extends Gtk.Stack {
     static get _nickPopover() {
         if (!this.__nickPopover)
@@ -363,19 +369,19 @@ var EntryArea = GObject.registerClass({
 
     pasteText(text, nLines) {
         this._confirmLabel.label =
-            ngettext("Paste %s line of text to public paste service?",
-                     "Paste %s lines of text to public paste service?",
+            ngettext('Paste %s line of text to public paste service?',
+                     'Paste %s lines of text to public paste service?',
                      nLines).format(nLines);
         this._uploadLabel.label =
-            ngettext("Uploading %s line of text to public paste service…",
-                     "Uploading %s lines of text to public paste service…",
+            ngettext('Uploading %s line of text to public paste service…',
+                     'Uploading %s lines of text to public paste service…',
                      nLines).format(nLines);
         this._setPasteContent(text);
     }
 
     pasteImage(pixbuf) {
-        this._confirmLabel.label = _("Upload image to public paste service?");
-        this._uploadLabel.label = _("Uploading image to public paste service…");
+        this._confirmLabel.label = _('Upload image to public paste service?');
+        this._uploadLabel.label = _('Uploading image to public paste service…');
         this._setPasteContent(pixbuf);
     }
 
@@ -396,9 +402,9 @@ var EntryArea = GObject.registerClass({
 
         let name = fileInfo.get_display_name();
         /* Translators: %s is a filename */
-        this._confirmLabel.label = _("Upload “%s” to public paste service?").format(name);
+        this._confirmLabel.label = _('Upload “%s” to public paste service?').format(name);
         /* Translators: %s is a filename */
-        this._uploadLabel.label = _("Uploading “%s” to public paste service…").format(name);
+        this._uploadLabel.label = _('Uploading “%s” to public paste service…').format(name);
         this._setPasteContent(file);
     }
 
@@ -407,9 +413,9 @@ var EntryArea = GObject.registerClass({
         let nick = this._room.channel.connection.self_contact.alias;
         if (this._room.type == Tp.HandleType.ROOM)
             /* translators: %s is a nick, #%s a channel */
-            title = _("%s in #%s").format(nick, this._room.display_name);
+            title = _('%s in #%s').format(nick, this._room.display_name);
         else
-            title = _("Paste from %s").format(nick);
+            title = _('Paste from %s').format(nick);
 
         let app = Gio.Application.get_default();
         try {
@@ -467,7 +473,7 @@ var EntryArea = GObject.registerClass({
         //
         // (set_aliases() would do what we want, but it's not
         // introspected)
-        Mainloop.timeout_add_seconds(MAX_NICK_UPDATE_TIME, () => {
+        GLib.timeout_add_seconds(GLib.PRIORITY_DEFAULT, MAX_NICK_UPDATE_TIME, () => {
             this._updateNick();
             return GLib.SOURCE_REMOVE;
         });
@@ -475,8 +481,9 @@ var EntryArea = GObject.registerClass({
 
     _updateNick() {
         let channel = this._room ? this._room.channel : null;
-        let nick = channel ? channel.connection.self_contact.alias
-                           : this._room ? this._room.account.nickname : '';
+        let nick = channel ?
+            channel.connection.self_contact.alias :
+            this._room ? this._room.account.nickname : '';
 
         this._nickLabel.width_chars = Math.max(nick.length, this._maxNickChars);
         this._nickLabel.label = nick;
