@@ -1,7 +1,6 @@
 /* exported RoomList RoomListHeader RoomRow */
 
 const { Gdk, Gio, GLib, GObject, Gtk, TelepathyGLib: Tp } = imports.gi;
-const Mainloop = imports.mainloop;
 
 const { AccountsMonitor } = imports.accountsMonitor;
 const { RoomManager } = imports.roomManager;
@@ -18,10 +17,18 @@ function _onPopoverVisibleChanged(popover) {
 
 var RoomRow = GObject.registerClass({
     Template: 'resource:///org/gnome/Polari/ui/room-list-row.ui',
-    InternalChildren: ['eventBox', 'icon', 'roomLabel', 'counter', 'eventStack'],
+    InternalChildren: [
+        'eventBox',
+        'icon',
+        'roomLabel',
+        'counter',
+        'eventStack'
+    ]
 }, class RoomRow extends Gtk.ListBoxRow {
     _init(room) {
-        super._init({ name: `RoomRow ${room.display_name}` });
+        super._init({
+            name: `RoomRow ${room.display_name}`
+        });
 
         this._room = room;
         this._popover = null;
@@ -63,7 +70,7 @@ var RoomRow = GObject.registerClass({
             if (connectionStatusChangedId)
                 this.account.disconnect(connectionStatusChangedId);
             if (this._connectingTimeoutId)
-                Mainloop.source_remove(this._connectingTimeoutId);
+                GLib.source_remove(this._connectingTimeoutId);
             this._connectingTimeoutId = 0;
         });
 
@@ -116,7 +123,7 @@ var RoomRow = GObject.registerClass({
         let status = this._getConnectionStatus();
         // Show loading indicator if joining a room takes more than 3 seconds
         if (status == Tp.ConnectionStatus.CONNECTED && !this._room.channel)
-            this._connectingTimeoutId = Mainloop.timeout_add_seconds(3, () => {
+            this._connectingTimeoutId = GLib.timeout_add_seconds(GLib.PRIORITY_DEFAULT, 3, () => {
                 this._connectingTimeoutId = 0;
 
                 if (this._room.channel)
@@ -183,7 +190,7 @@ var RoomRow = GObject.registerClass({
         if (!this._popover) {
             let menu = new Gio.Menu();
             let isRoom = this._room.type == Tp.HandleType.ROOM;
-            menu.append(isRoom ? _("Leave chatroom") : _("End conversation"),
+            menu.append(isRoom ? _('Leave chatroom') : _('End conversation'),
                         `app.leave-room(("${this._room.id}", ""))`);
 
             this._popover = Gtk.Popover.new_from_model(this, menu);
@@ -199,17 +206,19 @@ var RoomRow = GObject.registerClass({
 var RoomListHeader = GObject.registerClass({
     CssName: 'row',
     Template: 'resource:///org/gnome/Polari/ui/room-list-header.ui',
-    InternalChildren: ['label',
-                       'iconStack',
-                       'popoverStatus',
-                       'popoverTitle',
-                       'popoverPassword',
-                       'popoverConnect',
-                       'popoverDisconnect',
-                       'popoverReconnect',
-                       'popoverRemove',
-                       'popoverProperties',
-                       'spinner'],
+    InternalChildren: [
+        'label',
+        'iconStack',
+        'popoverStatus',
+        'popoverTitle',
+        'popoverPassword',
+        'popoverConnect',
+        'popoverDisconnect',
+        'popoverReconnect',
+        'popoverRemove',
+        'popoverProperties',
+        'spinner'
+    ]
 }, class RoomListHeader extends Gtk.MenuButton {
     _init(params) {
         this._account = params.account;
@@ -287,7 +296,7 @@ var RoomListHeader = GObject.registerClass({
         if (parent)
             parent.invalidate_sort();
 
-        let accessibleName = _("Network %s has an error").format(this._account.display_name);
+        let accessibleName = _('Network %s has an error').format(this._account.display_name);
         this.get_accessible().set_name(accessibleName);
     }
 
@@ -330,7 +339,7 @@ var RoomListHeader = GObject.registerClass({
         if (isError && this._spinner.active) {
             let spinnerTime = GLib.get_monotonic_time() - this._spinnerActivationTime;
             if (spinnerTime < MIN_SPINNER_TIME) {
-                Mainloop.timeout_add((MIN_SPINNER_TIME - spinnerTime) / 1000, () => {
+                GLib.timeout_add(GLib.PRIORITY_DEFAULT, (MIN_SPINNER_TIME - spinnerTime) / 1000, () => {
                     this._onConnectionStatusChanged();
                     return GLib.SOURCE_REMOVE;
                 });
@@ -358,14 +367,14 @@ var RoomListHeader = GObject.registerClass({
 
             /* Translators: This is an account name followed by a
                server address, e.g. "GNOME (irc.gnome.org)" */
-            let fullTitle = _("%s (%s)").format(accountName, server);
+            let fullTitle = _('%s (%s)').format(accountName, server);
             this._popoverTitle.label = (accountName == server) ? accountName : fullTitle;
             this._popoverStatus.label = `<sup>${this._getStatusLabel()}<${'/'}sup>`;
         } else {
             let styleContext = this._popoverStatus.get_style_context();
             styleContext.remove_class('dim-label');
 
-            this._popoverTitle.label = `<b>${_("Connection Problem")}<${'/'}b>`;
+            this._popoverTitle.label = `<b>${_('Connection Problem')}<${'/'}b>`;
             this._popoverStatus.label = this._getErrorLabel();
         }
     }
@@ -381,46 +390,46 @@ var RoomListHeader = GObject.registerClass({
 
     _getStatusLabel() {
         switch (this._getConnectionStatus()) {
-            case Tp.ConnectionStatus.CONNECTED:
-                return _("Connected");
-            case Tp.ConnectionStatus.CONNECTING:
-                return _("Connecting…");
-            case Tp.ConnectionStatus.DISCONNECTED:
-                return _("Offline");
-            default:
-                return _("Unknown");
+        case Tp.ConnectionStatus.CONNECTED:
+            return _('Connected');
+        case Tp.ConnectionStatus.CONNECTING:
+            return _('Connecting…');
+        case Tp.ConnectionStatus.DISCONNECTED:
+            return _('Offline');
+        default:
+            return _('Unknown');
         }
     }
 
     _getErrorLabel() {
         switch (this._account.connection_error) {
 
-            case Tp.error_get_dbus_name(Tp.Error.CERT_REVOKED):
-            case Tp.error_get_dbus_name(Tp.Error.CERT_INSECURE):
-            case Tp.error_get_dbus_name(Tp.Error.CERT_LIMIT_EXCEEDED):
-            case Tp.error_get_dbus_name(Tp.Error.CERT_INVALID):
-            case Tp.error_get_dbus_name(Tp.Error.ENCRYPTION_ERROR):
-            case Tp.error_get_dbus_name(Tp.Error.CERT_NOT_PROVIDED):
-            case Tp.error_get_dbus_name(Tp.Error.ENCRYPTION_NOT_AVAILABLE):
-            case Tp.error_get_dbus_name(Tp.Error.CERT_UNTRUSTED):
-            case Tp.error_get_dbus_name(Tp.Error.CERT_EXPIRED):
-            case Tp.error_get_dbus_name(Tp.Error.CERT_NOT_ACTIVATED):
-            case Tp.error_get_dbus_name(Tp.Error.CERT_HOSTNAME_MISMATCH):
-            case Tp.error_get_dbus_name(Tp.Error.CERT_FINGERPRINT_MISMATCH):
-            case Tp.error_get_dbus_name(Tp.Error.CERT_SELF_SIGNED):
-                return _("Could not connect to %s in a safe way.").format(this._account.display_name);
+        case Tp.error_get_dbus_name(Tp.Error.CERT_REVOKED):
+        case Tp.error_get_dbus_name(Tp.Error.CERT_INSECURE):
+        case Tp.error_get_dbus_name(Tp.Error.CERT_LIMIT_EXCEEDED):
+        case Tp.error_get_dbus_name(Tp.Error.CERT_INVALID):
+        case Tp.error_get_dbus_name(Tp.Error.ENCRYPTION_ERROR):
+        case Tp.error_get_dbus_name(Tp.Error.CERT_NOT_PROVIDED):
+        case Tp.error_get_dbus_name(Tp.Error.ENCRYPTION_NOT_AVAILABLE):
+        case Tp.error_get_dbus_name(Tp.Error.CERT_UNTRUSTED):
+        case Tp.error_get_dbus_name(Tp.Error.CERT_EXPIRED):
+        case Tp.error_get_dbus_name(Tp.Error.CERT_NOT_ACTIVATED):
+        case Tp.error_get_dbus_name(Tp.Error.CERT_HOSTNAME_MISMATCH):
+        case Tp.error_get_dbus_name(Tp.Error.CERT_FINGERPRINT_MISMATCH):
+        case Tp.error_get_dbus_name(Tp.Error.CERT_SELF_SIGNED):
+            return _('Could not connect to %s in a safe way.').format(this._account.display_name);
 
-            case Tp.error_get_dbus_name(Tp.Error.AUTHENTICATION_FAILED):
-                return _("%s requires a password.").format(this._account.display_name);
+        case Tp.error_get_dbus_name(Tp.Error.AUTHENTICATION_FAILED):
+            return _('%s requires a password.').format(this._account.display_name);
 
-            case Tp.error_get_dbus_name(Tp.Error.CONNECTION_FAILED):
-            case Tp.error_get_dbus_name(Tp.Error.CONNECTION_LOST):
-            case Tp.error_get_dbus_name(Tp.Error.CONNECTION_REPLACED):
-            case Tp.error_get_dbus_name(Tp.Error.SERVICE_BUSY):
-                return _("Could not connect to %s. The server is busy.").format(this._account.display_name);
+        case Tp.error_get_dbus_name(Tp.Error.CONNECTION_FAILED):
+        case Tp.error_get_dbus_name(Tp.Error.CONNECTION_LOST):
+        case Tp.error_get_dbus_name(Tp.Error.CONNECTION_REPLACED):
+        case Tp.error_get_dbus_name(Tp.Error.SERVICE_BUSY):
+            return _('Could not connect to %s. The server is busy.').format(this._account.display_name);
 
-            default:
-                return _("Could not connect to %s.").format(this._account.display_name);
+        default:
+            return _('Could not connect to %s.').format(this._account.display_name);
         }
     }
 });
@@ -458,36 +467,42 @@ class RoomList extends Gtk.ListBox {
                                   this._roomAdded.bind(this));
         this._roomManager.connect('room-removed',
                                   this._roomRemoved.bind(this));
-        this._roomManager.rooms.forEach(r => { this._roomAdded(this._roomManager, r); });
+        this._roomManager.rooms.forEach(r => this._roomAdded(this._roomManager, r));
 
         let app = Gio.Application.get_default();
-        let actions = [
-            { name: 'next-room',
-              handler: () => { this._moveSelection(Gtk.DirectionType.DOWN); } },
-            { name: 'previous-room',
-              handler: () => { this._moveSelection(Gtk.DirectionType.UP); } },
-            { name: 'first-room',
-              handler: () => { this._selectRoomAtIndex(0); } },
-            { name: 'last-room',
-              handler: () => {
-                  let nRows = this._roomManager.roomCount;
-                  this._selectRoomAtIndex(nRows - 1);
-              } },
-            { name: 'nth-room',
-              handler: (a, param) => {
-                  this._selectRoomAtIndex(param.get_int32() - 1);
-              } },
-            { name: 'next-pending-room',
-              handler: () => {
-                  this._moveSelectionFull(Gtk.DirectionType.DOWN,
-                                          row => row.hasPending);
-              } },
-            { name: 'previous-pending-room',
-              handler: () => {
-                  this._moveSelectionFull(Gtk.DirectionType.UP,
-                                          row => row.hasPending);
-              } }
-        ];
+        let actions = [{
+            name: 'next-room',
+            handler: () => this._moveSelection(Gtk.DirectionType.DOWN)
+        }, {
+            name: 'previous-room',
+            handler: () => this._moveSelection(Gtk.DirectionType.UP)
+        }, {
+            name: 'first-room',
+            handler: () => this._selectRoomAtIndex(0)
+        }, {
+            name: 'last-room',
+            handler: () => {
+                let nRows = this._roomManager.roomCount;
+                this._selectRoomAtIndex(nRows - 1);
+            }
+        }, {
+            name: 'nth-room',
+            handler: (a, param) => {
+                this._selectRoomAtIndex(param.get_int32() - 1);
+            }
+        }, {
+            name: 'next-pending-room',
+            handler: () => {
+                this._moveSelectionFull(Gtk.DirectionType.DOWN,
+                                        row => row.hasPending);
+            }
+        }, {
+            name: 'previous-pending-room',
+            handler: () => {
+                this._moveSelectionFull(Gtk.DirectionType.UP,
+                                        row => row.hasPending);
+            }
+        }];
         actions.forEach(a => {
             app.lookup_action(a.name).connect('activate', a.handler);
         });
@@ -527,7 +542,7 @@ class RoomList extends Gtk.ListBox {
     }
 
     _moveSelection(direction) {
-        this._moveSelectionFull(direction, () => { return true; });
+        this._moveSelectionFull(direction, () => true);
     }
 
     _moveSelectionFull(direction, testFunction) {
@@ -564,8 +579,8 @@ class RoomList extends Gtk.ListBox {
 
         let index = this._rowToRoomIndex(row.get_index());
         this.select_row(row);
-        this._moveSelection(index == 0 ? Gtk.DirectionType.DOWN
-                                       : Gtk.DirectionType.UP);
+        this._moveSelection(index == 0 ?
+            Gtk.DirectionType.DOWN : Gtk.DirectionType.UP);
 
         let newSelected = this.get_selected_row();
         if (newSelected != row)
@@ -580,9 +595,11 @@ class RoomList extends Gtk.ListBox {
         if (this._placeholders.has(account))
             return;
 
-        let placeholder = new Gtk.ListBoxRow({ selectable: false,
-                                               activatable: false,
-                                               no_show_all: true });
+        let placeholder = new Gtk.ListBoxRow({
+            selectable: false,
+            activatable: false,
+            no_show_all: true
+        });
         placeholder.account = account;
 
         this._placeholders.set(account, placeholder);
@@ -613,7 +630,7 @@ class RoomList extends Gtk.ListBox {
         this.add(row);
         this._roomRows.set(room.id, row);
 
-        row.connect('destroy', w => { this._roomRows.delete(w.room.id); });
+        row.connect('destroy', w => this._roomRows.delete(w.room.id));
         this._placeholders.get(room.account).hide();
     }
 
