@@ -74,20 +74,20 @@ class SASLAuthHandler {
         debug(`Auth status for server "${name}": ${statusString}`);
 
         switch (status) {
-            case SASLStatus.NOT_STARTED:
-            case SASLStatus.IN_PROGRESS:
-            case SASLStatus.CLIENT_ACCEPTED:
-                break;
+        case SASLStatus.NOT_STARTED:
+        case SASLStatus.IN_PROGRESS:
+        case SASLStatus.CLIENT_ACCEPTED:
+            break;
 
-            case SASLStatus.SERVER_SUCCEEDED:
-                this._proxy.AcceptSASLRemote();
-                break;
+        case SASLStatus.SERVER_SUCCEEDED:
+            this._proxy.AcceptSASLRemote();
+            break;
 
-            case SASLStatus.SUCCEEDED:
-            case SASLStatus.SERVER_FAILED:
-            case SASLStatus.CLIENT_FAILED:
-                this._channel.close_async(null);
-                break;
+        case SASLStatus.SUCCEEDED:
+        case SASLStatus.SERVER_FAILED:
+        case SASLStatus.CLIENT_FAILED:
+            this._channel.close_async(null);
+            break;
         }
     }
 
@@ -108,8 +108,8 @@ class TelepathyClient extends Tp.BaseClient {
     _init(params) {
         this._app = Gio.Application.get_default();
         this._app.connect('prepare-shutdown', () => {
-            [...this._pendingRequests.values()].forEach(r => { r.cancel(); });
-            [...this._pendingBotPasswords.keys()].forEach(a => { this._discardIdentifyPassword(a); });
+            [...this._pendingRequests.values()].forEach(r => r.cancel());
+            [...this._pendingBotPasswords.keys()].forEach(a => this._discardIdentifyPassword(a));
             this._app.release();
         });
         this._app.hold();
@@ -134,24 +134,31 @@ class TelepathyClient extends Tp.BaseClient {
     }
 
     _onPrepared() {
-        let actions = [
-            { name: 'message-user',
-              handler: this._onQueryActivated.bind(this) },
-            { name: 'leave-room',
-              handler: this._onLeaveActivated.bind(this) },
-            { name: 'connect-account',
-              handler: this._onConnectAccountActivated.bind(this) },
-            { name: 'disconnect-account',
-              handler: this._onDisconnectAccountActivated.bind(this) },
-            { name: 'reconnect-account',
-              handler: this._onReconnectAccountActivated.bind(this) },
-            { name: 'authenticate-account',
-              handler: this._onAuthenticateAccountActivated.bind(this) },
-            { name: 'save-identify-password',
-              handler: this._onSaveIdentifyPasswordActivated.bind(this) },
-            { name: 'discard-identify-password',
-              handler: this._onDiscardIdentifyPasswordActivated.bind(this) }
-        ];
+        let actions = [{
+            name: 'message-user',
+            handler: this._onQueryActivated.bind(this)
+        }, {
+            name: 'leave-room',
+            handler: this._onLeaveActivated.bind(this)
+        }, {
+            name: 'connect-account',
+            handler: this._onConnectAccountActivated.bind(this)
+        }, {
+            name: 'disconnect-account',
+            handler: this._onDisconnectAccountActivated.bind(this)
+        }, {
+            name: 'reconnect-account',
+            handler: this._onReconnectAccountActivated.bind(this)
+        }, {
+            name: 'authenticate-account',
+            handler: this._onAuthenticateAccountActivated.bind(this)
+        }, {
+            name: 'save-identify-password',
+            handler: this._onSaveIdentifyPasswordActivated.bind(this)
+        }, {
+            name: 'discard-identify-password',
+            handler: this._onDiscardIdentifyPasswordActivated.bind(this)
+        }];
         actions.forEach(a => {
             this._app.lookup_action(a.name).connect('activate', a.handler);
         });
@@ -199,8 +206,9 @@ class TelepathyClient extends Tp.BaseClient {
     }
 
     _onNetworkChanged(mon, connected) {
-        let presence = connected ? Tp.ConnectionPresenceType.AVAILABLE
-                                 : Tp.ConnectionPresenceType.OFFLINE;
+        let presence = connected ?
+            Tp.ConnectionPresenceType.AVAILABLE :
+            Tp.ConnectionPresenceType.OFFLINE;
         debug(`Network changed to ${connected ? 'available' : 'unavailable'}`);
 
         this._accountsMonitor.visibleAccounts.forEach(a => {
@@ -356,7 +364,7 @@ class TelepathyClient extends Tp.BaseClient {
     _onReconnectAccountActivated(action, parameter) {
         let accountPath = parameter.deep_unpack();
         let account = this._accountsMonitor.lookupAccount(accountPath);
-        account.reconnect_async((a, res) => { a.reconnect_finish(res); });
+        account.reconnect_async((a, res) => a.reconnect_finish(res));
     }
 
     _onAuthenticateAccountActivated(action, parameter) {
@@ -407,7 +415,7 @@ class TelepathyClient extends Tp.BaseClient {
         });
 
         let reason = Tp.ChannelGroupChangeReason.NONE;
-        message = message || _("Good Bye");
+        message = message || _('Good Bye');
         room.channel.leave_async(reason, message, (c, res) => {
             try {
                 c.leave_finish(res);
@@ -470,15 +478,19 @@ class TelepathyClient extends Tp.BaseClient {
     _processRequest(context, connection, channels, processChannel) {
         if (connection.protocol_name != 'irc') {
             let message = 'Not implementing non-IRC protocols';
-            context.fail(new Tp.Error({ code: Tp.Error.NOT_IMPLEMENTED,
-                                        message: message }));
+            context.fail(new Tp.Error({
+                code: Tp.Error.NOT_IMPLEMENTED,
+                message: message
+            }));
             return;
         }
 
         if (this._isAuthChannel(channels[0]) && channels.length > 1) {
             let message = 'Only one authentication channel per connection allowed';
-            context.fail(new Tp.Error({ code: Tp.Error.INVALID_ARGUMENT,
-                                        message: message }));
+            context.fail(new Tp.Error({
+                code: Tp.Error.INVALID_ARGUMENT,
+                message: message
+            }));
             return;
         }
 
@@ -544,9 +556,11 @@ class TelepathyClient extends Tp.BaseClient {
         notification.set_title(summary);
         notification.set_body(body);
 
-        let params = [room.account.object_path,
-                      room.channel_name,
-                      Utils.getTpEventTime()];
+        let params = [
+            room.account.object_path,
+            room.channel_name,
+            Utils.getTpEventTime()
+        ];
 
         let actionName, paramFormat;
         if (room.type == Tp.HandleType.ROOM) {
@@ -581,11 +595,11 @@ class TelepathyClient extends Tp.BaseClient {
         let accountName = room.account.display_name;
         /* Translators: Those are a botname and an accountName, e.g.
            "Save NickServ password for GNOME" */
-        let summary = _("Save %s password for %s?").format(data.botname, accountName);
-        let text = _("Identification will happen automatically the next time you connect to %s").format(accountName);
+        let summary = _('Save %s password for %s?').format(data.botname, accountName);
+        let text = _('Identification will happen automatically the next time you connect to %s').format(accountName);
         let notification = this._createNotification(room, summary, text);
 
-        notification.add_button_with_target(_("Save"), 'app.save-identify-password',
+        notification.add_button_with_target(_('Save'), 'app.save-identify-password',
                                             new GLib.Variant('o', accountPath));
 
         this._app.send_notification(this._getIdentifyNotificationID(accountPath), notification);
